==> lxqt-config-0.9.0.tar.xz: lxqt-config-0.9.0/lxqt-config-file-associations/translations/lxqt-config-file-associations_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Seletor de aplicações</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Escolha uma aplicação para:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>Aplicações para manipular JPEG</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>Novo subitem</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="85"/>
        <source>Other applications</source>
        <translation>Outras aplicações</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="86"/>
        <source>Applications that handle %1</source>
        <translation>Aplicações para manipular %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="114"/>
        <source>No applications found</source>
        <translation>Nenhuma aplicação encontrada</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="157"/>
        <location filename="../mimetypeviewer.cpp" line="208"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="204"/>
        <source>&amp;Change...</source>
        <translation>&amp;Mudar...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="209"/>
        <source>&amp;Choose...</source>
        <translation>Es&amp;colher...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Associação de ficheiros</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="56"/>
        <source>Default application</source>
        <translation>Aplicaçao pré-definida</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="68"/>
        <source>&amp;Choose...</source>
        <translation>Es&amp;colher...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="117"/>
        <source>TextLabel</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="124"/>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="144"/>
        <source>Patterns</source>
        <translation>Padrões</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="156"/>
        <source>*.txt *.xml</source>
        <translation>*.txt *.xml</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="173"/>
        <source>MIME type</source>
        <translation>Tipo MIME</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="191"/>
        <source>Icon</source>
        <translation>Ícone</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="198"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
</context>
</TS>

==> lxqt-config_0.14.0.orig.tar.xz: lxqt-config-0.14.0/lxqt-config-file-associations/translations/lxqt-config-file-associations_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Seletor de aplicações</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Escolha a aplicação para:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>Aplicações para manipular JPEG</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>Novo Subitem</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="113"/>
        <source>Other applications</source>
        <translation>Outras aplicações</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="114"/>
        <source>Applications that handle %1</source>
        <translation>Aplicações para manipular %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="151"/>
        <source>No applications found</source>
        <translation>Nenhuma aplicação encontrada</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="156"/>
        <location filename="../mimetypeviewer.cpp" line="207"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="203"/>
        <source>&amp;Change...</source>
        <translation>&amp;Alterar...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="208"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Escolher...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Associação de ficheiros</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="56"/>
        <source>Default application</source>
        <translation>Aplicação padrão</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="68"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Escolher...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="117"/>
        <source>TextLabel</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="124"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="144"/>
        <source>Patterns</source>
        <translation>Padrões</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="156"/>
        <source>*.txt *.xml</source>
        <translation>*.txt *.xml</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="173"/>
        <source>MIME type</source>
        <translation>Tipo MIME</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="191"/>
        <source>Icon</source>
        <translation>Ícone</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="198"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
</context>
</TS>
